@@ -22,7 +22,18 @@ Video Video::fromJson(const QJsonObject &obj, Video &video)
         video.m_genre = obj.value("genre"_L1).toString();
         video.m_genreUrl = obj.value("genreUrl"_L1).toString();
         parseArray(obj.value("authorThumbnails"_L1), video.m_authorThumbnails);
-        video.m_subCountText = obj.value("subCountText"_L1).toString();
+
+        // Invidious does this really stupid thing where it gives us /text/ for the sub count here.
+        // We need to parse it into some kind of number.
+        QString subCountText = obj.value("subCountText"_L1).toString();
+        if (subCountText.endsWith(QLatin1Char('M'))) {
+            video.m_subCount = subCountText.first(subCountText.length() - 1).toDouble() * 1000000;
+        } else if (subCountText.endsWith(QLatin1Char('K'))) {
+            video.m_subCount = subCountText.first(subCountText.length() - 1).toDouble() * 1000;
+        } else {
+            video.m_subCount = subCountText.toInt();
+        }
+
         video.m_allowRatings = obj.value("allowRatings"_L1).toBool(true);
         video.m_rating = obj.value("rating"_L1).toDouble(5.0);
         video.m_isListed = obj.value("isListed"_L1).toBool(true);
@@ -35,7 +46,14 @@ Video Video::fromJson(const QJsonObject &obj, Video &video)
         parseArray(obj.value(u"formatStreams"), video.m_combinedFormats);
         parseArray(obj.value(u"captions"), video.m_captions);
     } else if (isPeerTube) {
-        // TODO: peertube stub
+        auto account = obj.value("account"_L1).toObject();
+
+        VideoThumbnail thumbnail;
+        thumbnail.setUrl(QUrl(account["avatar"_L1].toObject()["path"_L1].toString()));
+        video.m_authorThumbnails.push_back(thumbnail);
+
+        video.m_dislikeCount = obj.value("dislikes"_L1).toInt();
+        video.m_likeCount = obj.value("likes"_L1).toInt();
     } else {
         video.m_author = obj.value("uploader"_L1).toString();
         parseArray(obj.value("tags"_L1), video.m_keywords);
@@ -46,7 +64,7 @@ Video Video::fromJson(const QJsonObject &obj, Video &video)
         thumbnail.setUrl(QUrl(obj.value("uploaderAvatar"_L1).toString()));
         video.m_authorThumbnails.push_back(thumbnail);
 
-        video.m_subCountText = QString::number(obj.value("uploaderSubscriberCount"_L1).toInt());
+        video.m_subCount = obj.value("uploaderSubscriberCount"_L1).toInt();
         parseArray(obj.value("relatedStreams"_L1), video.m_recommendedVideos);
         video.m_hlsUrl = QUrl(obj.value(u"hls").toString());
     }
@@ -94,9 +112,14 @@ QList<VideoThumbnail> Video::authorThumbnails() const
     return m_authorThumbnails;
 }
 
-QString Video::subCountText() const
+void Video::setAuthorThumbnails(const QList<QInvidious::VideoThumbnail> &thumbnails)
 {
-    return m_subCountText;
+    m_authorThumbnails = thumbnails;
+}
+
+qint32 Video::subCount() const
+{
+    return m_subCount;
 }
 
 bool Video::allowRatings() const
