@@ -15,20 +15,26 @@
 MpvObject::MpvObject(QQuickItem *parent)
     : MpvAbstractItem(parent)
 {
+    setProperty(QStringLiteral("hwdec"), QStringLiteral("auto-safe"));
+
     setProperty(QStringLiteral("terminal"), QStringLiteral("yes"));
     setProperty(QStringLiteral("keep-open"), QStringLiteral("always"));
     setProperty(QStringLiteral("audio-client-name"), QStringLiteral("org.kde.plasmatube"));
     setProperty(QStringLiteral("wayland-app-id"), QStringLiteral("org.kde.plasmatube"));
 
+    setProperty(QStringLiteral("msg-level"), QStringLiteral("all=warn"));
+
     observeProperty(QStringLiteral("duration"), MPV_FORMAT_DOUBLE);
     observeProperty(QStringLiteral("time-pos"), MPV_FORMAT_DOUBLE);
     observeProperty(QStringLiteral("pause"), MPV_FORMAT_FLAG);
 
     connect(mpvController(), &MpvController::propertyChanged, this, &MpvObject::onPropertyChanged, Qt::QueuedConnection);
     connect(mpvController(), &MpvController::fileLoaded, this, [=]() {
-        // Note that audio-add only works in a specific time, the best is right after the file is loaded.
-        // For more details on this issue, see https://github.com/flaviotordini/minitube/issues/155.
-        Q_EMIT command(QStringList() << QStringLiteral("audio-add") << m_audioUrl << QStringLiteral("select"));
+        if (!m_audioUrl.isEmpty()) {
+            // Note that audio-add only works in a specific time, the best is right after the file is loaded.
+            // For more details on this issue, see https://github.com/flaviotordini/minitube/issues/155.
+            Q_EMIT command(QStringList() << QStringLiteral("audio-add") << m_audioUrl << QStringLiteral("select"));
+        }
     });
 }
 
@@ -90,6 +96,11 @@ void MpvObject::seek(qreal offset)
     Q_EMIT command(QStringList() << QStringLiteral("add") << QStringLiteral("time-pos") << QString::number(offset));
 }
 
+void MpvObject::toggleStats()
+{
+    Q_EMIT command(QStringList() << QStringLiteral("script-binding") << QStringLiteral("stats/display-stats-toggle"));
+}
+
 bool MpvObject::stopped() const
 {
     return m_stopped;
